@@ -30,6 +30,7 @@ Uses cold backup strategy: restore recipes and volumes directly.
 """
 
 import json
+import os
 import subprocess
 import tempfile
 import shutil
@@ -39,11 +40,19 @@ from pathlib import Path
 from typing import List
 from contextlib import contextmanager
 
+from rich.console import Console
+from rich.prompt import Prompt
+
 from ..helpers.logging import get_logger
 from ..types import RestorePoint
 from ..helpers.config import Config
 from ..cores.repository_manager import KopiaRepository
 from ..helpers.constants import RECIPE_BACKUP_DIR, VOLUME_BACKUP_DIR, CONTAINER_START_TIMEOUT
+from ..helpers import (
+    check_file_conflicts,
+    create_file_backup,
+    copy_with_rollback,
+)
 
 logger = get_logger(__name__)
 
@@ -312,8 +321,13 @@ class RestoreManager:
                 print("\n2️⃣ Volume restoration:")
                 self._display_volume_restore_instructions(rp, restore_dir)
 
-            # 3) Restart instructions (only modern docker compose)
-            print("\n3️⃣ Service restart instructions:")
+            # 3) Interactive config copy (NEW in v3.1.0)
+            if recipe_dir.exists():
+                print("\n3️⃣ Configuration files:")
+                self._interactive_copy_configs(recipe_dir, rp.unit_name)
+
+            # 4) Restart instructions
+            print("\n4️⃣ Service restart instructions:")
             self._display_restart_instructions(recipe_dir)
 
             print("\n" + "=" * 60)
@@ -624,14 +638,223 @@ class RestoreManager:
         except Exception as e:
             logger.debug(f"Backup cleanup failed: {e}")
 
+    def _get_real_user_ids(self) -> tuple:
+        """
+        Get real user IDs when running with sudo.
+        
+        Returns:
+            (uid, gid, username) tuple
+        """
+        uid = int(os.environ.get('SUDO_UID', os.getuid()))
+        gid = int(os.environ.get('SUDO_GID', os.getgid()))
+        user = os.environ.get('SUDO_USER', 'root')
+        return uid, gid, user
+
+    def _copy_with_permissions(self, source_path: Path, target_dir: Path, uid: int, gid: int) -> int:
+        """
+        Copy files from source to target with proper permissions.
+        
+        Args:
+            source_path: Source file or directory
+            target_dir: Target directory
+            uid: User ID for ownership
+            gid: Group ID for ownership
+            
+        Returns:
+            Number of files copied
+        """
+        count = 0
+        
+        if source_path.is_file():
+            # Copy single file
+            target_file = target_dir / source_path.name
+            shutil.copy2(source_path, target_file)
+            os.chown(target_file, uid, gid)
+            os.chmod(target_file, 0o644)
+            count = 1
+            logger.debug(f"Copied {source_path.name} with permissions", extra={"target": str(target_file)})
+        elif source_path.is_dir():
+            # Copy all files from directory
+            for item in source_path.iterdir():
+                if item.is_file():
+                    target_file = target_dir / item.name
+                    shutil.copy2(item, target_file)
+                    os.chown(target_file, uid, gid)
+                    os.chmod(target_file, 0o644)
+                    count += 1
+                    logger.debug(f"Copied {item.name} with permissions", extra={"target": str(target_file)})
+        
+        return count
+
+    def _interactive_copy_configs(self, recipe_dir: Path, unit_name: str) -> None:
+        """
+        Interactively copy configuration files to deployment directory.
+        With conflict handling and VPS-optimized backups (Phase 2).
+        
+        Args:
+            recipe_dir: Path to recipes directory
+            unit_name: Name of the backup unit
+        """
+        console = Console()
+        
+        # Step 1: Collect files
+        compose_file = recipe_dir / "docker-compose.yml"
+        project_files_dir = recipe_dir / "project-files"
+        
+        files_to_copy = []
+        if compose_file.exists():
+            files_to_copy.append(compose_file)
+        if project_files_dir.exists():
+            files_to_copy.extend([f for f in project_files_dir.glob("*") if f.is_file()])
+        
+        if not files_to_copy:
+            logger.debug("No config files to copy")
+            return
+        
+        # Step 2: Display files
+        console.print("\n📁 [bold]Restored configuration files:[/bold]")
+        for file in files_to_copy:
+            console.print(f"   • {file.name}")
+        
+        # Step 3: Ask user - Copy?
+        copy = Prompt.ask(
+            "\n🎯 Copy files to deployment directory?",
+            choices=["yes", "no", "q"],
+            default="yes"
+        )
+        
+        if copy == "q":
+            return
+        
+        if copy == "no":
+            self._show_manual_instructions(recipe_dir)
+            return
+        
+        # Step 4: Loop for directory selection with conflict handling
+        default_target = f"/opt/stacks/{unit_name}"
+        
+        while True:
+            # Get target directory
+            target = Prompt.ask(
+                f"\n📂 Target directory",
+                default=default_target
+            )
+            target_path = Path(target).expanduser()
+            
+            # Check write permissions
+            parent_dir = target_path.parent if not target_path.exists() else target_path
+            if not os.access(parent_dir, os.W_OK):
+                console.print(f"[red]✗ No write permission for {parent_dir}[/red]")
+                console.print("Try running with sudo or choose different directory.")
+                retry = Prompt.ask("Try different directory?", choices=["yes", "no"], default="yes")
+                if retry == "no":
+                    return
+                continue
+            
+            # Create directory if needed
+            try:
+                target_path.mkdir(parents=True, exist_ok=True)
+            except Exception as e:
+                console.print(f"[red]✗ Cannot create directory: {e}[/red]")
+                continue
+            
+            # Check for conflicts using helper function
+            conflicts = check_file_conflicts(target_path, files_to_copy)
+            
+            if not conflicts:
+                # No conflicts, proceed to copy
+                console.print(f"✓ Target directory is ready")
+                break
+            
+            # Conflicts found - show them
+            console.print("\n⚠️  [bold yellow]Existing files detected:[/bold yellow]")
+            for conflict in conflicts:
+                console.print(f"   • {conflict.name}")
+            
+            console.print("\n[bold]What do you want to do?[/bold]")
+            console.print("1. Overwrite existing files")
+            console.print("2. Create backup first (recommended)")
+            console.print("3. Choose different directory")
+            console.print("4. Skip copying (manual restore)")
+            
+            choice = Prompt.ask("Your choice", choices=["1", "2", "3", "4"], default="2")
+            
+            if choice == "1":
+                # Overwrite without backup
+                console.print("\n⚠️  [yellow]Overwriting files without backup...[/yellow]")
+                break
+                
+            elif choice == "2":
+                # Create backups using helper function
+                console.print("\n📦 Creating backups (existing .bak files will be overwritten)...")
+                backup_files = []
+                try:
+                    for conflict in conflicts:
+                        backup = create_file_backup(conflict)
+                        backup_files.append(backup)
+                        console.print(f"   ✓ {conflict.name} → {backup.name}")
+                except Exception as e:
+                    console.print(f"\n[red]✗ Backup failed: {e}[/red]")
+                    console.print("Aborting copy operation.")
+                    return
+                
+                console.print(f"\n✓ Created {len(backup_files)} backup(s)")
+                console.print("💡 Previous .bak files were overwritten (only last backup is kept)")
+                break
+                
+            elif choice == "3":
+                # Different directory - loop continues
+                continue
+                
+            elif choice == "4":
+                # Skip copying
+                console.print("\n[yellow]Skipping copy operation.[/yellow]")
+                self._show_manual_instructions(recipe_dir)
+                return
+        
+        # Step 5: Copy with rollback using helper function
+        success, copied_files = copy_with_rollback(files_to_copy, target_path, console)
+        
+        if success:
+            console.print(f"\n✓ [bold green]Files copied to: {target_path}[/bold green]")
+            console.print(f"\n📄 Copied files:")
+            for file in files_to_copy:
+                console.print(f"   • {file.name}")
+            console.print(f"\n💡 [bold]To start:[/bold] cd {target_path} && docker compose up -d")
+        else:
+            console.print("\n[red]Copy operation failed. See logs for details.[/red]")
+            self._show_manual_instructions(recipe_dir)
+
+    def _show_manual_instructions(self, recipe_dir: Path) -> None:
+        """
+        Show manual copy instructions when user declines or copy fails.
+        
+        Args:
+            recipe_dir: Path to recipes directory
+        """
+        console = Console()
+        console.print("\n📋 [bold]Manual restore instructions:[/bold]")
+        console.print(f"\n1. Copy files to your deployment directory:")
+        console.print(f"   sudo cp -r {recipe_dir}/* /path/to/your/project/")
+        console.print(f"\n2. Fix permissions:")
+        console.print(f"   sudo chown -R $USER:$USER /path/to/your/project/")
+        console.print(f"\n3. Start containers:")
+        console.print(f"   cd /path/to/your/project && docker compose up -d")
+
     def _display_restart_instructions(self, recipe_dir: Path):
         """Show modern docker compose restart steps (no legacy fallback)."""
         compose_file = recipe_dir / "docker-compose.yml"
+        
         print("\n   🐳 Service Restart:")
         print("   " + "-" * 40)
+        
         if compose_file.exists():
-            print(f"   cd {recipe_dir}")
-            print(f"   docker compose up -d  # ensure volumes are restored BEFORE this")
+            print(f"")
+            print(f"   💡 After copying files to your target directory:")
+            print(f"      cd /your/target/directory")
+            print(f"      docker compose up -d")
+            print(f"")
         else:
+            print(f"   ⚠️  No docker-compose.yml found in backup")
             print(f"   Review the inspect files in: {recipe_dir}")
-            print(f"   Recreate containers with appropriate 'docker run' options")
\ No newline at end of file
+            print(f"   Recreate containers with appropriate 'docker run' options")
